.. _api_plot:

==============
Plotting (API)
==============

All plot types produced with the ``fancplot`` executable in :ref:`fancplot-executable` are also available
in the Python API. These plots are based on Matplotlib, the `Python plotting API <https://matplotlib.org/>`_,
and therefore highly customisable.

.. note::

    To follow along yourself with the examples in this section, please complete the
    :ref:`command line tutorial <analyse_hic>` first, so that all the necessary files have
    been generated in the output folder.

.. toctree::
   :maxdepth: 2

   Plotting basics <plot/plot_basics>
   Matrix plots <plot/matrix>
   Region and score plots <plot/region>
